==> eiffelstudio-18.07.10.1981.tar: F_code/C4/re198.c <==
/*
 * Code for class REFLECTOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re198.h"
#include "eif_macros.h"
#include "eif_built_in.h"
#include "eif_gen_conf.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F30_1572
static EIF_INTEGER_32 inline_F30_1572 (EIF_INTEGER_32 arg1)
{
	return eif_non_attached_type(arg1)
	;
}
#define INLINE_F30_1572
#endif
#ifndef INLINE_F30_1566
static int inline_F30_1566 (EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	return eif_gen_conf(arg1, arg2);
	;
}
#define INLINE_F30_1566
#endif
#ifndef INLINE_F439_3914
static EIF_REFERENCE inline_F439_3914 (EIF_INTEGER_32 arg1)
{
	return RTLNT(eif_decoded_type(arg1).id);
	;
}
#define INLINE_F439_3914
#endif
#ifndef INLINE_F30_1571
static int inline_F30_1571 (EIF_INTEGER_32 arg1)
{
	return eif_is_attached_type(arg1)
	;
}
#define INLINE_F30_1571
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {REFLECTOR}.field_conforms_to */
EIF_BOOLEAN F439_3885 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	RTGC;
	ti4_1 = inline_F30_1572(arg2);
	Result = EIF_TEST (inline_F30_1566(arg1, ti4_1));
	return Result;
}

/* {REFLECTOR}.new_tuple_from_tuple */
EIF_REFERENCE F439_3890 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,arg2);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	Result = inline_F439_3914(arg1);
	loc1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (Result);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (arg2);
	if ((EIF_BOOLEAN) (loc1 <= ti4_1)) {
		tb1 = (EIF_BOOLEAN) eif_builtin_TUPLE_object_comparison (arg2);
		if (tb1) {
			F868_6494(RTCW(Result));
		}
		for (;;) {
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 0L)) || (EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL))) break;
			loc2 = F868_6470(RTCW(arg2), loc1);
			tr1 = RTCCL(loc2);
			tb1 = F868_6498(RTCW(Result), tr1, loc1);
			if (tb1) {
				tr1 = RTCCL(loc2);
				F868_6503(RTCW(Result), tr1, loc1);
			} else {
				Result = (EIF_REFERENCE) NULL;
			}
			loc1--;
		}
	} else {
		RTLE;
		return (EIF_REFERENCE) NULL;
	}
	RTLE;
	return Result;
}

/* {REFLECTOR}.is_attached_type */
EIF_BOOLEAN F439_3895 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) EIF_TEST (inline_F30_1571(arg1));
}

/* {REFLECTOR}.c_new_tuple_instance_of */
EIF_REFERENCE F439_3914 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	Result = inline_F439_3914 ((EIF_INTEGER_32) arg1);
	RTLE;
	return Result;
}

void EIF_Minit198 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/re198.c <==
/*
 * Code for class REFLECTOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re198.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {REFLECTOR}.field_conforms_to */
EIF_BOOLEAN F223_3588 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	RTGC;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_detachable_type (arg2);
	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to (arg1, ti4_1);
	return Result;
}

/* {REFLECTOR}.new_tuple_from_tuple */
EIF_REFERENCE F223_3593 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,arg2);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	Result = (EIF_REFERENCE) eif_builtin_REFLECTOR_c_new_tuple_instance_of (arg1);
	loc1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (Result);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (arg2);
	if ((EIF_BOOLEAN) (loc1 <= ti4_1)) {
		tb1 = (EIF_BOOLEAN) eif_builtin_TUPLE_object_comparison (arg2);
		if (tb1) {
			F875_6572(RTCW(Result));
		}
		for (;;) {
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 <= ((EIF_INTEGER_32) 0L)) || (EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL))) break;
			loc2 = F875_6548(RTCW(arg2), loc1);
			tr1 = RTCCL(loc2);
			tb1 = F875_6576(RTCW(Result), tr1, loc1);
			if (tb1) {
				tr1 = RTCCL(loc2);
				F875_6581(RTCW(Result), tr1, loc1);
			} else {
				Result = (EIF_REFERENCE) NULL;
			}
			loc1--;
		}
	} else {
		RTLE;
		return (EIF_REFERENCE) NULL;
	}
	RTLE;
	return Result;
}

/* {REFLECTOR}.is_attached_type */
EIF_BOOLEAN F223_3598 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_is_attached_type (arg1);
}

/* {REFLECTOR}.c_new_tuple_instance_of */
EIF_REFERENCE F223_3617 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	Result = (EIF_REFERENCE) eif_builtin_REFLECTOR_c_new_tuple_instance_of (arg1);
	RTLE;
	return Result;
}

void EIF_Minit198 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
